from uuid import UUID

from seatsio.pagination.pageFetcher import PageFetcher
from seatsio.pagination.pagedIterator import PagedIterator
from seatsio.ticketBuyers.addTicketBuyerIdsResponse import AddTicketBuyerIdsResponse
from seatsio.ticketBuyers.removeTicketBuyerIdsResponse import RemoveTicketBuyerIdsResponse


class TicketBuyersClient:

    def __init__(self, http_client):
        self.http_client = http_client

    def add(self, ids):
        filtered_ids = [str(uuid) for uuid in ids if uuid is not None]
        response = self.http_client \
            .url("/ticket-buyers") \
            .post({"ids": filtered_ids})
        return AddTicketBuyerIdsResponse(response.json())

    def remove(self, ids):
        filtered_ids = [str(i) for i in ids if i is not None]
        response = self.http_client \
            .url("/ticket-buyers") \
            .delete({"ids": filtered_ids})
        return RemoveTicketBuyerIdsResponse(response.json())

    def list_all(self):
        return PagedIterator(PageFetcher(UUID, self.http_client, "/ticket-buyers"))



from uuid import UUID


class AddTicketBuyerIdsResponse:

    def __init__(self, data):
        self.added = [UUID(uuid) for uuid in data.get("added", [])]
        self.already_present = [UUID(uuid) for uuid in data.get("alreadyPresent", [])]



from uuid import UUID


class RemoveTicketBuyerIdsResponse:

    def __init__(self, data):
        self.removed = [UUID(uuid) for uuid in data.get("removed", [])]
        self.not_present = [UUID(uuid) for uuid in data.get("notPresent", [])]



from setuptools import setup, find_packages

with open('README.md') as f:
    readme = f.read()

setup(
    name='seatsio',
    version='v81.13.0',
    description='The official Seats.io Python client library',
    author='The seats.io dev team',
    author_email='hello@seats.io',
    url='https://github.com/seatsio/seatsio-python',
    license="MIT",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    packages=find_packages()
)
